import os
import unittest

from mock import patch
from .api import Zodiac


class Args():
    def __init__(self):
        self.model_group_hash = "testhash"
        self.transactions = ["foo"]
        self.attributes = ["bar"]


class TestAPI(unittest.TestCase):
    def setUp(self):
        user = os.environ.get("APIUSER")
        password = os.environ.get("APIPASS")
        self.api = Zodiac(user, password)

    def test_format_url(self):
        url = self.api._format_url("{api}/{version}/foo/bar")
        self.assertEqual("https://dashboard.zodiacmetrics.com/api/v1/foo/bar", url)

    def test_login_values(self):
        self.assertEqual(
                self.api.company,
                "37fb20db"
                )
        self.assertIn("User-Authorization-Token", self.api.session.headers)

    def test_upload(self):
        uri = self.api._create_upload_location("~/python-client/LICENSE")
        self.assertIn("LICENSE", uri)

    def test_create_email_upload(self):
        uri = self.api._create_upload_location("~/python-client/MANIFEST")
        self.assertIn("MANIFEST", uri)

    def test_upload_emails(self):
        with open("FOO.csv", "w+") as foo:
            foo.write("figgy,pudding")
        record = self.api.upload_emails("FOO.csv")
        self.assertIn("FOO.csv", record)

    def test_submit_job(self):
        with patch('zodiac.api.Zodiac._post') as mock_foo:
            with patch('zodiac.api.Zodiac.upload_file') as mock_bar:
                mock_foo.return_value = "figgy"
                mock_bar.return_value = "pudding"
                args = Args()
                self.api.submit_job(args)
                mock_bar.assert_called()
                mock_foo.assert_called_once()

    def test_datasets(self):
        ds = self.api.list_datasets()
        self.assertIn("test.csv", ds)

    def test_get_download_url(self):
        res = self.api.get_download_url("test.csv")
        self.assertIn("https://raw-datasets.storage.googleapis.com/v1/clienttest/2017/08/28/", res)
